@@ -81,7 +81,6 @@ def create_report(
     if font_options is None:
         font_options = config["fonts"]
 
-
     curtime = time.time()
     logger.info("Started reading data source")
     ds = read_data_source(data_source, options)
@@ -102,7 +101,7 @@ def create_report(
         university_school,
         pdf,
         config,
-        font_options
+        font_options,
     )
     logger.info("Finished creating title page: {round(time.time() - curtime, 2)}s")
 
@@ -218,11 +217,10 @@ def create_title_page(
         title_font_size = font_options["title_size"]
         if "title_sub_font" in font_options.keys():
             title_sub_font = font_options["title_sub_font"]
-            title_sub_font_size = font_options["title_sub_size"]
+            font_options["title_sub_size"]
         else:
             title_sub_font = font_options["title_font"]
-            title_sub_font_size = font_options["title_size"]
-
+            font_options["title_size"]
 
         pdf = fonts.add_font_choices_to_pdf(pdf, None)
         pdf.set_font(title_font, "", title_font_size)
@@ -313,7 +311,9 @@ def calc_number_of_contents_pages(data_frame: object) -> int:
     return count
 
 
-def create_report_order_sections(ds: object, pdf: object, config: dict, font_options: dict) -> object:
+def create_report_order_sections(
+    ds: object, pdf: object, config: dict, font_options: dict
+) -> object:
     """Create report order sections.
 
     Filter function that splits the data frame (ds) into smaller dataframes
@@ -480,15 +480,21 @@ def create_report_section_pages(section, pdf, config, font_options):
 
             if i % 3 == 2:
                 image_offset += 165
-                pdf = create_report_page_compact(amp, pdf, image_offset, config, font_options)
+                pdf = create_report_page_compact(
+                    amp, pdf, image_offset, config, font_options
+                )
                 pdf.add_page()
             elif i % 3 == 1:
                 image_offset += 85
-                pdf = create_report_page_compact(amp, pdf, image_offset, config, font_options)
+                pdf = create_report_page_compact(
+                    amp, pdf, image_offset, config, font_options
+                )
                 if (i + 1) == len(amp_list):
                     pdf.add_page()
             else:
-                pdf = create_report_page_compact(amp, pdf, image_offset, config, font_options)
+                pdf = create_report_page_compact(
+                    amp, pdf, image_offset, config, font_options
+                )
                 if (i + 1) == len(amp_list):
                     pdf.add_page()
     return pdf
@@ -636,7 +642,9 @@ def create_report_page_table(amphibian_data, pdf, config, font_options):
     return pdf
 
 
-def create_report_page_compact(amp: object, pdf, image_offset, config, font_options) -> object:
+def create_report_page_compact(
+    amp: object, pdf, image_offset, config, font_options
+) -> object:
     """Create report page compact.
 
     Creates a report page with a more compact style.
@@ -654,8 +662,8 @@ def create_report_page_compact(amp: object, pdf, image_offset, config, font_opti
     """
     header_font = font_options["header_font"]
     header_font_size = font_options["header_size"]
-    paragraph_font = font_options["paragraph_font"]
-    paragraph_font_size = font_options["paragraph_size"]
+    font_options["paragraph_font"]
+    font_options["paragraph_size"]
     pdf.start_section(name=amp.get_short_name(), level=3)
     pdf.set_font(header_font, "ib", (header_font_size / 4) + 4)
     pdf.ln(5)
@@ -681,8 +689,8 @@ def create_report_page_table_compact(amphibian_data, pdf, config, font_options):
         pdf - pdf object
 
     """
-    header_font = font_options["header_font"]
-    header_font_size = font_options["header_size"]
+    font_options["header_font"]
+    font_options["header_size"]
     paragraph_font = font_options["paragraph_font"]
     paragraph_font_size = font_options["paragraph_size"]
 
@@ -781,8 +789,8 @@ def insert_species_images_compact(amp, pdf, image_offset, config, font_options):
     WIDTH = 210
     header_font = font_options["header_font"]
     header_font_size = font_options["header_size"]
-    paragraph_font = font_options["paragraph_font"]
-    paragraph_font_size = font_options["paragraph_size"]
+    font_options["paragraph_font"]
+    font_options["paragraph_size"]
     pdf.set_font(header_font, "", (header_font_size / 4) + 4)
     if amp.has_image_url():
         pdf.image(
@@ -947,7 +955,6 @@ def render_toc(pdf, outline):
 
 
 if __name__ == "__main__":
-    logger.debug(DIR_PATH)
     logger.debug(os.getcwd())
     args = sys.argv
 
